paulicirc.utils.options
=======================

.. automodule:: paulicirc.utils.options

PauliCircOptions
----------------

.. autoclass:: paulicirc.utils.options.PauliCircOptions
    :show-inheritance:
    :members:
    :special-members: __call__, __getitem__, __setitem__

options
-------

.. autodata:: paulicirc.utils.options.options
